# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V50
33
34
63
64
1478
1479
1563
1564
1565
1568
1748
1749
2041
2042
3853
3858
3860
3861
6146
6148
6152
6154
6468
6470
10082
10084
11513
11514
11518
11519
11822
11823
11859
11861
42510
42511
43126
43128
65045
65047
65110
65112
65281
65282
65311
65312
71108
71110
72817
72818
END
