# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V34
189
190
2931
2932
3444
3445
3882
3883
11517
11518
43057
43058
65857
65858
65909
65911
68029
68030
68091
68092
68168
68169
69243
69244
69414
69415
73681
73683
74852
74853
126126
126127
126268
126269
END
