# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V48
180
181
712
713
716
717
735
736
3191
3192
3204
3205
3841
3845
3846
3848
3849
3851
4048
4050
4051
4052
6150
6151
8189
8190
43124
43126
43260
43261
70005
70006
70107
70108
71105
71106
71264
71277
72162
72163
72255
72256
72261
72262
72350
72353
72816
72817
END
